@@ -1,5 +1,5 @@
 se.fixef <- function(model) {
-    stopifnot(is(model, "mer"))
+    #stopifnot(is(model, "mer"))
     sqrt(diag(vcov(model)))
 }
 
